def write(*text):
	print("".join(text), end="")

def read():
	return input()